cal.SubscriptionsByUser (Subscriptions) — amici1

# `cal.SubscriptionsByUser` (Subscriptions)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: calendar>`

- `<django.db.models.fields.BooleanField: is_hidden>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- Delete (delete_selected) : Delete this record

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

Filter parameters

- `<django.db.models.fields.related.ForeignKey: user>`

## Filter parameters